@@ -44,10 +44,13 @@ def _setop(
 
 
 class SetCommandsMixin:
-    version: Tuple[int]
-    _db: Database
     _scan: Callable[..., Any]
 
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        super(SetCommandsMixin, self).__init__(*args, **kwargs)
+        self.version: Tuple[int]
+        self._db: Database
+
     @command((Key(set), bytes), (bytes,))
     def sadd(self, key: CommandItem, *members: bytes) -> int:
         old_size = len(key.value)
@@ -188,10 +191,7 @@ class SetCommandsMixin:
 
     @command((Key(set),), (Key(set),))
     def pfcount(self, *keys: CommandItem) -> int:
-        """
-        Return the approximated cardinality of
-        the set observed by the HyperLogLog at key(s).
-        """
+        """Return the approximated cardinality of the set observed by the HyperLogLog at key(s)."""
         return len(self.sunion(*keys))
 
     @command((Key(set), Key(set)), (Key(set),))
